
/********************************************************************************************************************************/
/*																																*/
/*SAS Program: FluNearYou.sas																									*/		
/*																																*/
/*Description: Descriptive analyses for Arizona Flu Near You data																*/
/*																																*/
/*Creates datasets:	work.rawFNY; work.FNY; 																						*/
/*																																*/
/*Original Variables: week_of	 state	 zip	 participants	 users	 household	 ili	 gastro	 other	 no_symptoms fever	*/
/*				cough	sore_throat	chills	fatigue	nausea	diarrhea	bodyache	headache									*/
/********************************************************************************************************************************/
/********************************************************************************************************************************/
/*Purpose: Import and analyze Flu Near You data 																				*/
/* 																																*/
/*    Importation of Flu Near You Data 																							*/
/* 																																*/
/*    Requested by the Flu Near You Epi-hack group																				*/
/*																																*/
/*    Date of program start: 9/29/2015																							*/
/* 																																*/
/*		This program can be done in three steps:																				*/
/*			Step 1. Jurisdiction defines 3 variables																			*/
/*			Step 2. Import data																									*/
/*			Step 3. Clean data / create variables												 								*/
/* 			Step 4. Create summary datasets for all data, state data, and county data											*/
/*	 Pre-requisite: FluNearYou data from datasets dashboard.																		*/
/********************************************************************************************************************************/

/********************************************/
/*Step 1. Jurisdiction defines 3 variables	*/
/********************************************/

/*Jurisdiction defined.  Place file named "FNY" in a folder and indicate folder's path below*/
%let filename = \\pubhs-filesrv03\dctrl$\\EPI\Syndromic Surveillance\Syndrome-specific Files - Influenza-like Illness\Flu Near You\Data Files;

/*Jurisdiction defined.  Change state and county information to meet needs*/
%let state = AZ;
%let county = Maricopa; /*Place county name here and define zip codes in county*/

/********************************************/
/*Step 2. Import data						*/
/********************************************/
LIBNAME fny "&filename";

/*Set your own filepath*/

%let datasource = "&filename\FNY.csv";

%let datasource="\\pubhs-filesrv03\dctrl$\\EPI\Syndromic Surveillance\Syndrome-specific Files - Influenza-like Illness\Flu Near You\Data Files\FNY_ZIPDATA_from_2012-08-27_to_2015-09-27.csv";

DATA work.rawFNY;
	infile &datasource delimiter = ',' MISSOVER DSD lrecl=32767 firstobs=2;

	informat week_of ANYDTDTE10.;
	informat state $2.;
	informat zip best12.;
	informat participants best12.;
	informat users best12.;
	informat household best12.;
	informat ili best12.;
	informat other best12.;
	informat no_symptoms best12.;
	informat fever best12.;
	informat cough best12.;
	informat sore_throat best12.;
	informat chills best12.;
	informat fatigue best12.;
	informat nausea best12.;
	informat diarrhea best12.;
	informat bodyache best12.;
	informat headache best12.;
 
	format week_of mmddyy10.;
	format state $2.;
	format zip z5.;					/*Eliminates leading zeros in zipcode*/
	format participants best12.;
	format users best12.;
	format household best12.;
	format ili best12.;
	format other best12.;
	format no_symptoms best12.;
	format fever best12.;
	format cough best12.;
	format sore_throat best12.;
	format chills best12.;
	format fatigue best12.;
	format nausea best12.;
	format diarrhea best12.;
	format bodyache best12.;
	format headache best12.;
 
	input
	week_of
	state
	zip
	participants
	users
	household
	ili
	other
	no_symptoms
	fever
	cough
	sore_throat
	chills
	fatigue
	nausea
	diarrhea
	bodyache
	headache
	;

	/*Renaming variables with "FNY" prefix*/
	rename week_of = FNY_week_of;
	rename state = FNY_state;
	rename zip = FNY_zip;
	rename participants = FNY_participants;
	rename users = FNY_users;
	rename household = FNY_household;
	rename ili = FNY_ili;
	rename other = FNY_other;
	rename no_symptoms = FNY_no_symptoms;
	rename fever = FNY_fever;
	rename cough = FNY_cough;
	rename sore_throat = FNY_sorethroat;
	rename chills = FNY_chills;
	rename fatigue = FNY_fatigue;
	rename nausea = FNY_nausea;
	rename diarrhea = FNY_diarrhea;
	rename bodyache = FNY_bodyache;
	rename headache = FNY_headache;

	/*Label variables*/
	LABEL
		week_of = "Weeks starting Monday"
		state = "State"
		zip = "Zip code"
		participants = "Total participants"
		users = "Total users"
		household = "Total household members"
		ili = "ILI syndrome(N)"
		other = "Other symptoms(N)"
		no_symptoms = "No symptoms(N)"
		fever = "Fever(N)"
		cough = "Cough(N)"
		sore_throat = "Sore throat(N)"
		chills = "Chills(N)"
		fatigue = "Fatigue(N)"
		nausea = "Nausea(N)"
		diarrhea = "Diarrhea(N)"
		bodyache = "Body aches(N)"
		headache = "Headache(N)"
	;
run;

/*Code for data checks:*/
/*PROC CONTENTS DATA=work.rawFNY varnum; RUN;
/*PROC PRINT DATA=work.rawFNY (OBS=100); RUN;

/********************************************/
/*Step 3. Clean data / create variables		*/
/********************************************/

PROC FORMAT;
	VALUE fMMWRweek 1 = "40"
					2 = "41"
					3 = "42"
					4 = "43"
					5 = "44"
					6 = "45"
					7 = "46"
					8 = "47"
					9 = "48"
					10 = "49"
					11 = "50"
					12 = "51"
					13 = "52"
					14 = "53"
					15 = "01"
					16 = "02"
					17 = "03"
					18 = "04"
					19 = "05"
					20 = "06"
					21 = "07"
					22 = "08"
					23 = "09"
					24 = "10"
					25 = "11"
					26 = "12"
					27 = "13"
					28 = "14"
					29 = "15"
					30 = "16"
					31 = "17"
					32 = "18"
					33 = "19"
					34 = "20"
					35 = "21"
					36 = "22"
					37 = "23"
					38 = "24"
					39 = "25"
					40 = "26"
					41 = "27"
					42 = "28"
					43 = "29"
					44 = "30"
					45 = "31"
					46 = "32"
					47 = "33"
					48 = "34"
					49 = "35"
					50 = "36"
					51 = "37"
					52 = "38"
					53 = "39";


DATA work.FNY (drop=_a);
	set work.rawFNY;

	IF FNY_zip = . OR FNY_week_of = . THEN delete; 	/*Eliminate rows with no zip or week_of*/

	/*Jurisdiction defined.  Create county or jurisdiction variable*/
	/*Create county variable using zip codes*/
	IF 	FNY_zip IN (85001, 85002, 85003, 85004, 85005, 85006, 85007, 85008, 85009, 85010,  
					85011, 85012, 85013, 85014, 85015, 85016, 85017, 85018, 85019, 85020, 
					85021, 85022, 85023, 85024, 85025, 85026, 85027, 85028, 85029, 85030,
					85031, 85032, 85033, 85034, 85035, 85036, 85037, 85038, 85039, 85040,
					85041, 85042, 85043, 85044, 85045, 85046, 	  	 85048,        85050,
					85051,        85053, 85054,   						           85060,
					85061, 85062, 85063, 85064, 85065, 85066, 85067, 85068, 85069, 85070, 
					85071, 85072, 85073, 85074, 85075, 85076,        85078, 85079, 85080,
					       85082, 85083,        85085, 85086, 85087, 
													   		  85097, 85098, 
													   		  85217,
						   85142,
							 											           85190,
					85201, 85202, 85203, 85204, 85205, 85206, 85207, 85208, 85209, 85210,
					85211, 85212, 85213, 85214, 85215, 85216, 
									     85224, 85225, 85226, 
								  85233, 85234,        85236, 
									     85244,        85246,        85248, 85249, 85250, 
					85251, 85252, 85253, 85254, 85255, 85256, 85257, 85258, 85259, 85260, 
					85261, 85262, 85263, 85264,        85266, 85267, 85268, 85269,  
					85271, 			     85274, 85275, 		  85277,			   85280,
					85281, 85282, 85283, 85284, 85285, 85286, 85287,  
											    85295, 85296, 85297, 85298, 85299, 
					85301, 85302, 85303, 85304, 85305, 85306, 85307, 85308, 85309, 85310,
					85311, 85312,  							  85318,       		   85320, 
						   85322, 85323,               85326, 85327,        85329, 
					85331,  					85335, 		  85337, 85338, 85339, 85340,
						   85342, 85343, 		85345,  
					85351, 		  85353, 85354, 85355, 			     85358,
					85361, 		  85363, 
						   85372, 85373, 85374, 85375, 85376, 85377, 85378, 85379, 85380, 
					85381, 85382, 85383,  		85385, 	      85387, 85388, 	   85390,
						   85392, 			    85395, 85396) THEN FNY_county ="&county";


	/*Assign MMWR weeks*/
		/*Years with 52 weeks*/
            do _a = 1 to 52;
		          /*2011*/
				  if intnx('week', '26dec2010'd, _a) le FNY_week_of le intnx('week', '01jan2011'd, _a, 'same') then FNY_mmwr_wk = _a;
                  /*2012*/
				  if intnx('week', '25dec2011'd, _a) le FNY_week_of le intnx('week', '31dec011'd, _a, 'same') then 	FNY_mmwr_wk = _a;
				  /*2013*/
				  if intnx('week', '23dec2012'd, _a) le FNY_week_of le intnx('week', '29dec2012'd, _a, 'same') then FNY_mmwr_wk = _a;
				  /*2015*/
				  if intnx('week', '28dec2014'd, _a) le FNY_week_of le intnx('week', '03jan2015'd, _a, 'same') then FNY_mmwr_wk = _a;
				  /*2016*/
				  if intnx('week', '03jan2016'd, _a) le FNY_week_of le intnx('week', '09jan2016'd, _a, 'same') then FNY_mmwr_wk = _a;
			end;

		/*Years with 53 weeks*/
            do _a = 1 to 53;
				  /*2014*/
				  if intnx('week', '22dec2013'd, _a) le FNY_week_of le intnx('week', '28dec2013'd, _a, 'same') then FNY_mmwr_wk = _a;
			end;

		/*Add leading zeros to mmwr week variable to match cdc variable*/
			format FNY_mmwr_wk z2.;

		/*Create FNY_Xaxis_order for MMWR week*/
			if FNY_mmwr_wk >= 40 then FNY_Xaxis_order = (FNY_mmwr_wk - 39);
				else FNY_Xaxis_order = (FNY_mmwr_wk + 14);

			format FNY_Xaxis_order fMMWRweek.;

		/*Create new variable for year*/

			if FNY_week_of <= '29dec2012'd then FNY_yr = '2012';
				else if FNY_week_of <= '28dec2013'd then FNY_yr = '2013';
				else if FNY_week_of <= '03jan2015'd then FNY_yr = '2014';
				else if FNY_week_of <= '02jan2016'd then FNY_yr = '2015';

		/*Create "yr/MMWR week" variable matching variable between CDC and FNY*/

			IF FNY_mmwr_wk < 10 THEN FNY_yrweek = cat(FNY_yr, "0", FNY_mmwr_wk);
				ELSE FNY_yrweek = cat(FNY_yr, FNY_mmwr_wk);

		/*Create new variable for flu season*/

			if 201140 <= FNY_yrweek < 201239 then FNY_fluseason = '2011-2012';
				else if 201240 <= FNY_yrweek < 201339 then FNY_fluseason = '2012-2013';
				else if 201340 <= FNY_yrweek < 201439 then FNY_fluseason = '2013-2014';
				else if 201440 <= FNY_yrweek < 201539 then FNY_fluseason = '2014-2015';
				else if 201540 <= FNY_yrweek < 201639 then FNY_fluseason = '2015-2016';

		/*Create new variables for year and season
			if FNY_week_of <= '01oct2012'd then FNY_fluseason = '2011-2012';
				else if FNY_week_of <= '30sep2013'd then FNY_fluseason = '2012-2013';
				else if FNY_week_of <= '29sep2014'd then FNY_fluseason = '2013-2014';
				else if FNY_week_of <= '12oct2015'd then FNY_fluseason = '2014-2015';
				else FNY_fluseason = '2015-2016';*/

		/*Create ILI%*/
			FNY_ili_pct = FNY_ili/FNY_participants;

		/*Create non-ILI count*/
			FNY_nonili = FNY_participants - FNY_ili;

		/*Label variables*/
		LABEL
		FNY_county = "County"
		FNY_mmwr_wk = "MMWR Week"
		FNY_Xaxis_order = "X Axis Order"
		FNY_fluseason = "Flu Season"
		FNY_yr = "Year"
		FNY_yrweek = "Year, MMWR Week"
		FNY_ili_pct = "ILI(%)"
		;
	run;

/*Code for data checks:*/
PROC CONTENTS data=work.FNY varnum; RUN;
PROC PRINT data=work.FNY(OBS=500);
	var FNY_week_of FNY_fluseason FNY_mmwr_wk;
	where FNY_fluseason = "2014-2015";
RUN;

/********************************************/
/*Step 4. Create summary datasets for all	*/
/*		  data, state data, and county data */
/********************************************/

/*Create a summary dataset of all FNY sites (National Activity Levels)*/
%macro summary_all (yrs, season);
proc sql;
    create table FNY_&yrs._all as
	    select distinct FNY_mmwr_wk, 
		sum(FNY_ili) as FNY_ili_&yrs,
		sum(FNY_participants) as FNY_participants_&yrs,
		(sum(FNY_participants) - sum(FNY_ili)) as FNY_nonili_&yrs, 
		round(sum(FNY_ili)/sum(FNY_participants)*100, 0.1) as FNY_ili_pct_&yrs, 
		FNY_fluseason,
		FNY_Xaxis_order
    from work.FNY
	where FNY_fluseason = "&season"
	group by FNY_mmwr_wk;
quit;
%mend;

%summary_all (1516, 2015-2016)
%summary_all (1415, 2014-2015)
%summary_all (1314, 2013-2014)
%summary_all (1213, 2012-2013);

/*Create a summary dataset of State-specific FNY (State Activity Levels)*/
%macro state_summary (yrs, season, state);
proc sql;
    create table FNY_&yrs._&state as
	    select distinct FNY_mmwr_wk, 
		FNY_state, 
		sum(FNY_ili) as FNY_ili_&yrs._&state,
		sum(FNY_participants) as FNY_participants_&yrs._&state,
		(sum(FNY_participants) - sum(FNY_ili)) as FNY_nonili_&yrs._&state, 
		round(sum(FNY_ili)/sum(FNY_participants)*100, 0.1) as FNY_ili_pct_&yrs._&state, 
		FNY_fluseason,
		FNY_Xaxis_order
    from work.FNY
	where FNY_fluseason="&season" and FNY_state="&state"
	group by FNY_mmwr_wk;
quit;
%mend;

%state_summary (1516, 2015-2016, &state)
%state_summary (1415, 2014-2015, &state)
%state_summary (1314, 2013-2014, &state)
%state_summary (1213, 2012-2013, &state);

/*Create a summary dataset of County-specific FNY (State Activity Levels)*/
%macro county_summary (yrs, season, county);
proc sql;
    create table fny_&yrs._&county as
	    select distinct FNY_mmwr_wk, 
		FNY_county, 
		sum(FNY_ili) as fny_ili_&yrs._&county,
		sum(FNY_participants) as FNY_participants_&yrs._&county,
		(sum(FNY_participants) - sum(FNY_ili)) as FNY_nonili_&yrs._&county, 
		round(sum(FNY_ili)/sum(FNY_participants)*100, 0.1) as fny_ili_pct_&yrs._&county, 
		FNY_fluseason,
		FNY_Xaxis_order
    from work.FNY
	where FNY_fluseason="&season" and FNY_county in ("&county")
	group by FNY_mmwr_wk;
quit;
%mend;
%county_summary (1516, 2015-2016, &county)
%county_summary (1415, 2014-2015, &county)
%county_summary (1314, 2013-2014, &county)
%county_summary (1213, 2012-2013, &county);

/*Merge datasets*/

DATA work.FNY_mergesummaries (drop= FNY_fluseason FNY_state);
	merge
		FNY_1516_all 		FNY_1415_all 		FNY_1314_all 		FNY_1213_all 
		FNY_1516_&state 	FNY_1415_&state 	FNY_1314_&state 	FNY_1213_&state
		FNY_1516_&county 	FNY_1415_&county 	FNY_1314_&county 	FNY_1213_&county		/*Add counties if desired*/
		;
	by FNY_mmwr_wk;
run;

/*Create a dataset for flu season (MMWR weeks 40 through 20)*/
DATA work.FNY_tot1 work.FNY_tot2;
	set work.FNY_mergesummaries;
	IF 21 <= FNY_mmwr_wk < 40 THEN delete;
		
	IF FNY_mmwr_wk <= 20 then output FNY_tot2;
		ELSE output fny_tot1;
run;

DATA work.FNY_fluseason_data;
	set work.fny_tot1 work.fny_tot2; 
run;

/********************************************/
/*Step 5. Print report						*/
/********************************************/

/******************Report Production START***********************/

/*Create the PDF file*/
ODS PDF FILE = "&filename\FluNearYou_Report_%sysfunc(date(),mmddyyd10.).pdf" STARTPAGE=YES;
OPTIONS ORIENTATION=PORTRAIT NODATE NONUMBER;
ODS NOPROCTITLE; /*Removes procedure names from output*/
FOOTNOTE "This Flu Near You Report was produced on %sysfunc(date(),mmddyyd10.)";

/*************************************************************/
/*Figure 1. Counts and Proportions of ILI Cases per MMWR Week*/

/*State Data; Season 2015-2016*/
PROC SGPLOT DATA=work.FNY_mergesummaries;
	VBAR FNY_Xaxis_order / RESPONSE = FNY_ili_1516_&state 					 FILLATTRS=(COLOR=STEELBLUE)			  			 LEGENDLABEL="&state ILI Cases (N)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1516_&state 	Y2AXIS BREAK LINEATTRS=(COLOR=BLACK pattern=1 THICKNESS=0.5) LEGENDLABEL="&state ILI Cases / Participants (%)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1516 		Y2AXIS BREAK LINEATTRS=(COLOR=INDIANRED pattern=2 THICKNESS=0.5) LEGENDLABEL="National ILI Cases / Participants (%)";

	XAXIS LABEL="MMWR Week" FITPOLICY=ROTATETHIN;
	YAXIS LABEL="ILI Case Count (N)" GRID VALUES=(0 to 30 by 5);
	Y2AXIS LABEL="ILI Cases / Participants (%)" VALUES=(0 to 10 by 1);
	TITLE "Figure 1a. Counts of ILI reported to Flu Near You in &state by MMWR Week";
	TITLE2 "Flu Season: 2015 - 2016";
run;

/*State Data; Season 2014-2015*/
PROC SGPLOT DATA=work.FNY_mergesummaries;
	VBAR FNY_Xaxis_order / RESPONSE = FNY_ili_1415_&state 					 FILLATTRS=(COLOR=STEELBLUE)			  			 LEGENDLABEL="&state ILI Cases (N)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1415_&state 	Y2AXIS BREAK LINEATTRS=(COLOR=BLACK pattern=1 THICKNESS=0.5) LEGENDLABEL="&state ILI Cases / Participants (%)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1415 		Y2AXIS BREAK LINEATTRS=(COLOR=INDIANRED pattern=2 THICKNESS=0.5) LEGENDLABEL="National ILI Cases / Participants (%)";

	XAXIS LABEL="MMWR Week" FITPOLICY=ROTATETHIN;
	YAXIS LABEL="ILI Case Count (N)" GRID VALUES=(0 to 30 by 5);
	Y2AXIS LABEL="ILI Cases / Participants (%)" VALUES=(0 to 10 by 1);
	TITLE "Figure 1b. Counts of ILI reported to Flu Near You in &state by MMWR Week";
	TITLE2 "Flu Season: 2014 - 2015";
run;

/*State Data; Season 2013-2014*/
PROC SGPLOT DATA=work.FNY_mergesummaries;
	VBAR  FNY_Xaxis_order / RESPONSE = FNY_ili_1314_&state 					 FILLATTRS=(COLOR=STEELBLUE)			  			 LEGENDLABEL="&state ILI Cases (N)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1314_&state 	Y2AXIS BREAK LINEATTRS=(COLOR=BLACK pattern=1 THICKNESS=0.5) LEGENDLABEL="&state ILI Cases / Participants (%)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1314 		Y2AXIS BREAK LINEATTRS=(COLOR=INDIANRED pattern=2 THICKNESS=0.5) LEGENDLABEL="National ILI Cases / Participants (%)";

	XAXIS LABEL="MMWR Week" FITPOLICY=ROTATETHIN;
	YAXIS LABEL="ILI Case Count (N)" GRID VALUES=(0 to 30 by 5);
	Y2AXIS LABEL="ILI Cases / Participants (%)" VALUES=(0 to 10 by 1);
	TITLE "Figure 1c. Counts of ILI reported to Flu Near You in &state by MMWR Week";
	TITLE2 "Flu Season: 2013 - 2014";
run;

/*State Data; Season 2012-2013*/
PROC SGPLOT DATA=work.FNY_mergesummaries;
	VBAR FNY_Xaxis_order / RESPONSE = FNY_ili_1213_&state 					 FILLATTRS=(COLOR=STEELBLUE)			  		 	 LEGENDLABEL="&state ILI Cases (N)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1213_&state 	Y2AXIS BREAK LINEATTRS=(COLOR=BLACK pattern=1 THICKNESS=0.5) LEGENDLABEL="&state ILI Cases / Participants (%)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1213 		Y2AXIS BREAK LINEATTRS=(COLOR=INDIANRED pattern=2 THICKNESS=0.5) LEGENDLABEL="National ILI Cases / Participants (%)";

	XAXIS LABEL="MMWR Week" FITPOLICY=ROTATETHIN;
	YAXIS LABEL="ILI Case Count (N)" GRID VALUES=(0 to 110 by 10);
	Y2AXIS LABEL="ILI Cases / Participants (%)" VALUES=(0 to 30 by 5);
	TITLE "Figure 1d. Counts of ILI reported to Flu Near You in &state by MMWR Week";
	TITLE2 "Flu Season: 2012 - 2013";
run;

/*************************************************************/
/*Figure 2. Proportions of ILI Cases per MMWR Week*/

PROC SGPLOT DATA=work.FNY_fluseason_data;
	SERIES X = FNY_Xaxis_order Y = FNY_ili_pct_1213_&state / BREAK LINEATTRS = (COLOR=GREEN PATTERN=4 THICKNESS=0.5 PCT) MARKERATTRS = (SIZE=0.3 PCT COLOR=GREEN SYMBOL=TRIANGLE) LEGENDLABEL="2012-13";
	SERIES X = FNY_Xaxis_order Y = FNY_ili_pct_1314_&state / BREAK LINEATTRS = (COLOR=BLUE PATTERN=3 THICKNESS=0.5 PCT) MARKERATTRS = (SIZE=0.3 PCT COLOR=BLUE SYMBOL=CIRCLE) LEGENDLABEL="2013-14";
	SERIES X = FNY_Xaxis_order Y = FNY_ili_pct_1415_&state / BREAK LINEATTRS = (COLOR=BLACK PATTERN=2 THICKNESS=0.5 PCT) MARKERATTRS = (SIZE=0.3 PCT COLOR=BLACK SYMBOL=SQUARE) LEGENDLABEL="2014-15";
	/*SERIES X = FNY_Xaxis_order Y = FNY_ili_pct_1516_&state / BREAK LINEATTRS = (COLOR=BLACK PATTERN=1 THICKNESS=0.5 PCT) MARKERATTRS = (SIZE=0.3 PCT COLOR=RED SYMBOL=SQUARE) LEGENDLABEL="2015-16";*/

	XAXIS LABEL="MMWR Week" GRID VALUES= (1 TO 34 BY 2);
/*(40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20);*/
	YAXIS LABEL="ILI Cases / Participants (%)" VALUES=(0 TO 25 BY 5);
	TITLE "Figure 2. Proportions of ILI reported to Flu Near You in &state by MMWR Week";
	TITLE2 "Data from Flu Seasons: 2012 - 2016";
run;

/*************************************************************/
/*Figure 3. Counts of ILI Cases and non-ILI Cases per MMWR Week*/
PROC SGPLOT DATA=work.FNY_mergesummaries;
	VBAR FNY_Xaxis_order / RESPONSE=FNY_participants_1415_&state LEGENDLABEL="&state Participants (N)";
	VBAR FNY_Xaxis_order / RESPONSE=FNY_ili_1415_&state LEGENDLABEL="&state ILI Cases (N)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1415_&state Y2AXIS LEGENDLABEL="&state ILI Cases / Participants (%)" BREAK LINEATTRS = (COLOR=BLACK PATTERN=1 THICKNESS=0.5 PCT);

	XAXIS LABEL="MMWR Week" FITPOLICY=ROTATETHIN;
	YAXIS LABEL="Count (N)" VALUES=(0 to 350 by 50);
	Y2AXIS LABEL="ILI Cases / Participants (%)" VALUES=(0 to 25 by 5);
	TITLE "Figure 3b. Counts of Participants and ILI Cases per MMWR Week";
	TITLE2 "Flu Season: 2014 - 2015";
run;

PROC SGPLOT DATA=work.FNY_mergesummaries;
	VBAR FNY_Xaxis_order / RESPONSE=FNY_participants_1314_&state LEGENDLABEL="&state Participants (N)";
	VBAR FNY_Xaxis_order / RESPONSE=FNY_ili_1314_&state LEGENDLABEL="&state ILI Cases (N)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1314_&state Y2AXIS LEGENDLABEL="&state ILI Cases / Participants (%)" BREAK LINEATTRS = (COLOR=BLACK PATTERN=1 THICKNESS=0.5 PCT);

	XAXIS LABEL="MMWR Week" FITPOLICY=ROTATETHIN;
	YAXIS LABEL="Count (N)" VALUES=(0 to 350 by 50);
	Y2AXIS LABEL="ILI Cases / Participants (%)" VALUES=(0 to 25 by 5);
	TITLE "Figure 3c. Counts of Participants and ILI Cases per MMWR Week";
	TITLE2 "Flu Season: 2013 - 2014";
run;


PROC SGPLOT DATA=work.FNY_mergesummaries;
	VBAR FNY_Xaxis_order / RESPONSE=FNY_participants_1213_&state LEGENDLABEL="&state Participants (N)";
	VBAR FNY_Xaxis_order / RESPONSE=FNY_ili_1213_&state LEGENDLABEL="&state ILI Cases (N)";
	VLINE FNY_Xaxis_order / RESPONSE = FNY_ili_pct_1213_&state Y2AXIS LEGENDLABEL="&state ILI Cases / Participants (%)" BREAK LINEATTRS = (COLOR=BLACK PATTERN=1 THICKNESS=0.5 PCT);

	XAXIS LABEL="MMWR Week" FITPOLICY=ROTATETHIN;
	YAXIS LABEL="Count (N)" VALUES=(0 to 850 by 50);
	Y2AXIS LABEL="ILI Cases / Participants (%)" VALUES=(0 to 25 by 5);
	TITLE "Figure 3d. Counts of Participants and ILI Cases per MMWR Week";
	TITLE2 "Flu Season: 2012 - 2013";
run;

/*************************************************************/
/*Table.  Line list of Flu Near You reports; 2012 - 2015 (all Maricopa County)*/

PROC REPORT data=work.FNY NOWINDOWS HEADLINE;

	where FNY_state= "&state";
	COLUMN FNY_week_of FNY_mmwr_wk FNY_ili FNY_participants FNY_ILIpercent;

	DEFINE FNY_mmwr_wk / GROUP;
	DEFINE FNY_week_of / GROUP ORDER=DATA;
	DEFINE FNY_ili / ANALYSIS SUM;
	DEFINE FNY_participants / ANALYSIS SUM;
	DEFINE FNY_ILIpercent / COMPUTED '% participants with ILI' format=5.1;
	COMPUTE FNY_ILIpercent;
		FNY_ILIpercent = (FNY_ili.SUM / FNY_participants.SUM)*100;
	ENDCOMP;

	TITLE "Table. Influenza-like illness reported each week in &state ; Flu Near You 2012 - 2015";
run;

ODS PDF CLOSE; /*Close the PDF file*/

/******************Report Production END***********************/

/*****************************************************************END OF CLEANED CODE 10/19/15********************************************************************/
